YARP 2.1.6 (2007-07-26)                                                {#v2_1_6}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.1.5...v2.1.6`):

```
    45	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    12	Alessandro Scalzo <alessandro.scalzo@iit.it>
    12	YARP Developers <yarp0-devel@lists.sourceforge.net>
    10	Alexandre Bernardino <alex@isr.ist.utl.pt>
     6	Lorenzo Natale <lorenzo.natale@iit.it>
     5	Carlos Beltran-Gonzalez <carlos.beltran@iit.it>
     3	Francesco Nori <francesco.nori@iit.it>
     3	Giorgio Metta <giorgio.metta@iit.it>
     3	Jonas Ruesch <ruesch@ifi.uzh.ch>
```
